explain: Explain details of an object

explainR Documentation

Explain details of an object

Description

This is a generic function which gives more details about an object than print, and is more focussed on human readable output than str.

See Also

dplyr::explain for more information.

Examples

p <- mtcars %>% ggvis(x = ~cyl) %>% layer_bars()
explain(p)

ggvis documentation built on Feb. 10, 2026, 5:07 p.m.