Learn R Programming

ggvis (version 0.4.1)

cocaine: Cocaine seizures in the US.

Description

This dataset comes from STRIDE, the System to Retrieve Information from Drug Evidence. It contains all concaine seizures in the US from 2007 that have a known weight.

Usage

cocaine

Arguments

format

Data frame with 3380 observations of 5 variables.

source

http://www.justice.gov/dea/resource-center/stride-data.shtml

Use

Use of this data requires your agreement to refer to your analyses as "unvalidated DEA data and to claim authorship and responsibility for any inferences and/or conclusions you may draw from this information."