Usage
ggvis_scale(property, name = property, label = name, type = NULL,
domain = NULL, range = NULL, reverse = NULL, round = NULL, ...,
subclass = NULL, override = NULL)is.ggvis_scale(x)
Arguments
property
The property to which the scale applies, such as "x", "y",
"fill", etc.
name
Name of the scale, such as "x", "y", "fill", etc. Can also be an
arbitrary name like "foo".
label
Label for the scale. Used for axis or legend titles.
type
Type of scale. Should be one of "linear", "ordinal", "time",
"utc", "linear", "log", "pow", "sqrt", "quantile", "quantize", "threshold".
domain
The domain of the scale, representing the set of data values.
For ordinal scales, a character vector; for quantitative scales, a numeric
vector of length two. Either value (but not both) may be NA, in which
case domainMin or domainMax
range
The range of the scale, representing the set of visual values.
For numeric values, the range can take the form of a two-element array with
minimum and maximum values. For ordinal data, the range may by an array of
desired output values, which are mapped t
reverse
If true, flips the scale range.
round
If true, rounds numeric output values to integers. This can be
helpful for snapping to the pixel grid.
...
other named arguments.
subclass
Class name for subclass. Will have scale_ prepended.
override
Should the domain specified by this ggvis_scale object
override other ggvis_scale objects for the same scale? Useful when domain is
manually specified. For example, by default, the domain of the scale
will contain the range of the data, but when this is T
x
object to test for scale-ness