view_static creates a static web page in a temporary directory;
view_dynamic generate a dynamic shiny app and launches it.
print automatically picks between the two.## S3 method for class 'ggvis':
print(x, dynamic = NA, launch = interactive(), ...)view_static(x, plot_id = rand_id("plot_"), dest = tempfile(pattern =
"ggvis"))
view_dynamic(x, plot_id = rand_id("plot_"), port = NULL, quiet = FALSE)
view_dynamic if TRUE, view_static if
FALSE. The default, NA, chooses automatically based on the
presence of reactives or interactive inputs in x.TRUE, will launch plot in a viewer/browser. If
FALSE returns an object that you can print() to launch.view_dynamic and
view_static ?from print.TRUE show status messages from Shiny. (Default is
FALSE.)