vega_data_parser: Determine the vega data type for a vector

View source: R/vector_type.R

vega_data_parserR Documentation

Determine the vega data type for a vector

Description

This is used to specify the data type so that the appropriate parser is used when Vega receives the data.

Usage

vega_data_parser(x)

Arguments

x

A vector.


ggvis documentation built on Feb. 10, 2026, 5:07 p.m.